#!/usr/bin/perl
use warnings;
use strict;
use lib ('lib');
use Test::More 'no_plan';
use Petal;

$Petal::BASE_DIR = './t/data/';
$Petal::DISK_CACHE = 0;
$Petal::MEMORY_CACHE = 0;
$Petal::TAINT = 1;

my $template = new Petal ('interpolate.xml');

my $string = $template->process ( first_name => 'Aurelia', last_name => 'Fernandez' );
unlike ($string, qr/\<\?/);
